@@ -120,6 +120,7 @@ bool LoginJobPrivate::sasl_interact()
                 interact->len = strlen((const char *) interact->result);
                 break;
             }
+            Q_FALLTHROUGH();
         case SASL_CB_USER:
             qCDebug(KIMAP_LOG) << "SASL_CB_[USER|AUTHNAME]: '" << userName << "'";
             interact->result = strdup(userName.toUtf8().constData());
@@ -356,6 +357,7 @@ void LoginJob::handleResponse(const Response &response)
             } else {
                 qCWarning(KIMAP_LOG) << "STARTTLS not supported by server!";
                 setError(UserDefinedError);
+                setErrorText(i18n("STARTTLS is not supported by the server, try using SSL/TLS instead."));
                 emitResult();
             }
             break;
@@ -529,11 +531,6 @@ void LoginJobPrivate::sslResponse(bool response)
 void LoginJob::setEncryptionMode(EncryptionMode mode)
 {
     Q_D(LoginJob);
-    if (mode == SslV2 || mode == SslV3 || mode == SslV3_1 || mode == AnySslVersion) {
-        mode = SSLorTLS;
-    } else if (mode == TlsV1) {
-        mode = STARTTLS;
-    }
     d->encryptionMode = mode;
 }
 
